import { useAjax } from '@/Hook/useAjax';
import { delCorpRelationApi, getCorpRelationListApi } from '@/services/adqV3/global';
import { PlusOutlined, SearchOutlined } from '@ant-design/icons';
import { Button, message, Popconfirm, Table } from 'antd';
import React, { useEffect, useState } from 'react';
import AddWechatTieUp from './addWechatTieUp';


/**
 * 企微关系链
 * @returns 
 */
const WechatTieUp: React.FC<{ adAccountId?: number }> = ({ adAccountId }) => {

    /**********************************/
    const [queryParamsNew, setQueryParamsNew] = useState<{ pageNum: number, pageSize: number }>({ pageNum: 1, pageSize: 10 })
    const [visible, setVisible] = useState<boolean>(false)

    const getCorpRelationList = useAjax((params) => getCorpRelationListApi(params))
    const delCorpRelation = useAjax((params) => delCorpRelationApi(params))
    /**********************************/

    useEffect(() => {
        if (adAccountId) {
            getCorpRelationList.run({ adAccountId, ...queryParamsNew })
        }
    }, [adAccountId, queryParamsNew]);

    /**
     * 删除
     * @param id 
     */
    const handleDel = (id: number) => {
        delCorpRelation.run(id).then((res) => {
            if (res) {
                message.success('删除成功')
                getCorpRelationList.refresh()
            }
        })
    }

    return <>
        <div className="flexStart" style={{ gap: 8, marginBottom: 16 }}>
            <Button type="primary" icon={<SearchOutlined />} loading={getCorpRelationList.loading} onClick={() => getCorpRelationList.refresh()}>刷新</Button>
            <Button
                type="primary"
                icon={<PlusOutlined />}
                onClick={() => {
                    setVisible(true)
                }}
            >新增</Button>
        </div>

        <Table
            columns={[
                {
                    title: '企业名称',
                    dataIndex: 'corpName',
                    key: 'corpName',
                    width: 150,
                    ellipsis: true,
                    render(value) {
                        return <span style={{ fontSize: 12 }}>{value}</span>
                    },
                },
                {
                    title: '企业ID',
                    dataIndex: 'corpId',
                    key: 'corpId',
                    width: 300,
                    ellipsis: true,
                    render(value) {
                        return <span style={{ fontSize: 12 }}>{value}</span>
                    },
                },
                {
                    title: '投放端企业ID',
                    dataIndex: 'tencentCorpId',
                    key: 'tencentCorpId',
                    width: 300,
                    ellipsis: true,
                    render(value) {
                        return <span style={{ fontSize: 12 }}>{value}</span>
                    },
                },
                {
                    title: '广告账户',
                    dataIndex: 'adAccountId',
                    key: 'adAccountId',
                    align: 'center',
                    width: 90,
                    render(value) {
                        return <span style={{ fontSize: 12 }}>{value}</span>
                    },
                },
                {
                    title: '创建时间',
                    dataIndex: 'createTime',
                    key: 'createTime',
                    width: 140,
                    ellipsis: true,
                    render(value) {
                        return <span style={{ fontSize: 12 }}>{value}</span>
                    },
                },
                {
                    title: '创建人',
                    dataIndex: 'createByName',
                    key: 'createByName',
                    align: 'center',
                    width: 80,
                    render(value) {
                        return <span style={{ fontSize: 12 }}>{value}</span>
                    },
                },
                {
                    title: '更新时间',
                    dataIndex: 'updateTime',
                    key: 'updateTime',
                    width: 140,
                    ellipsis: true,
                    render(value) {
                        return <span style={{ fontSize: 12 }}>{value}</span>
                    },
                },
                {
                    title: '更新人',
                    dataIndex: 'updateByName',
                    key: 'updateByName',
                    align: 'center',
                    width: 80,
                    render(value) {
                        return <span style={{ fontSize: 12 }}>{value}</span>
                    },
                },
                {
                    title: '操作',
                    dataIndex: 'cz',
                    key: 'cz',
                    width: 300,
                    render(_, record) {
                        return <Popconfirm
                            title="确定删除?"
                            onConfirm={() => handleDel(record.id)}
                        >
                            <a style={{ color: 'red', fontSize: 12 }}>删除</a>
                        </Popconfirm>
                    },
                },
            ]}
            dataSource={getCorpRelationList.data?.records || []}
            loading={getCorpRelationList.loading}
            scroll={{ x: 1000 }}
            pagination={{
                current: queryParamsNew.pageNum,
                pageSize: queryParamsNew.pageSize,
                total: getCorpRelationList.data?.total,
                onChange: (pageNum, pageSize) => setQueryParamsNew({ pageNum, pageSize }),
            }}
            size="small"
            bordered
            rowKey="id"
        />

        {/* 新增 */}
        {visible && <AddWechatTieUp
            adAccountId={adAccountId as number}
            visible={visible}
            onChange={() => {
                getCorpRelationList.refresh()
                setVisible(false)
            }}
            onClose={() => {
                setVisible(false)
            }}
        />}
    </>;
};

export default React.memo(WechatTieUp);